@@ -68,6 +68,7 @@ class RsyncProgressBar:
     senderre = re.compile("\[sender\] i=(\d+) ", re.S)
     # get number of receivce file from info rsync rtream
     receiverre = re.compile("recv_generator\(.+,([0-9]+)\)", re.S)
+    receiverre_bytes = re.compile(b"recv_generator\(.+,([0-9]+)\)", re.S)
     pipe = None
     maximum = 1
     copyStarting = False
@@ -130,7 +131,10 @@ class RsyncProgressBar:
                 s = self.pipe.stdout.readline()
             if len(s) == 0:
                 break
-            q = self.receiverre.search(s)
+            try:
+                q = self.receiverre.search(s)
+            except TypeError:
+                q = self.receiverre_bytes.search(s)
             if q:
                 self.value = int(q.groups()[0])
 
@@ -152,9 +156,14 @@ class RsyncProgressBar:
                 s = self.pipe.stdout.readline()
             if len(s) == 0:
                 break
-            if s.startswith("rsync:"):
-                self.errors.append(s)
-            q = self.receiverre.search(s)
+            try:
+                if s.startswith("rsync:"):
+                    self.errors.append(s)
+                q = self.receiverre.search(s)
+            except TypeError:
+                if s.startswith(b"rsync:"):
+                    self.errors.append(s)
+                q = self.receiverre_bytes.search(s)
             if q:
                 if not self.copyStarting:
                     self.parent.endTask()
